@@ -2,7 +2,7 @@ from django import get_version
 from django.template import engines
 from django.test import TestCase
 
-DJANGO3 = get_version() >= "3"
+DJANGO_VERSION = get_version()
 
 
 def html_39x27(html):
@@ -11,7 +11,7 @@ def html_39x27(html):
 
     See https://docs.djangoproject.com/en/dev/releases/3.0/#miscellaneous
     """
-    if not DJANGO3:
+    if DJANGO_VERSION < "3":
         return html.replace("&#x27;", "&#39;")
     return html
 
